@@ -5,15 +5,11 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/gruntwork-io/terragrunt/internal/ctyhelper"
 	"github.com/gruntwork-io/terragrunt/internal/remotestate"
-
 	"github.com/gruntwork-io/terragrunt/pkg/log"
 	"github.com/huandu/go-clone"
 
 	"github.com/gruntwork-io/terragrunt/internal/cache"
-	"github.com/gruntwork-io/terragrunt/internal/strict/controls"
-
 	"github.com/hashicorp/hcl/v2"
 	"github.com/zclconf/go-cty/cty"
 
@@ -32,7 +28,6 @@ const (
 	TerraformBlock
 	TerraformSource
 	TerragruntFlags
-	TerragruntInputs
 	TerragruntVersionConstraints
 	RemoteStateBlock
 	FeatureFlagsBlock
@@ -114,12 +109,6 @@ type terragruntRemoteState struct {
 	Remain      hcl.Body                `hcl:",remain"`
 }
 
-// terragruntInputs is a struct that can be used to only decode the inputs block.
-type terragruntInputs struct {
-	Inputs *cty.Value `hcl:"inputs,attr"`
-	Remain hcl.Body   `hcl:",remain"`
-}
-
 // terragruntEngine is a struct that can only be used to decode the engine block.
 type terragruntEngine struct {
 	Engine *EngineConfig `hcl:"engine,block"`
@@ -501,60 +490,6 @@ func PartialParseConfig(ctx *ParsingContext, l log.Logger, file *hclparse.File,
 			if decoded.IamWebIdentityToken != nil {
 				output.IamWebIdentityToken = *decoded.IamWebIdentityToken
 			}
-		case TerragruntInputs:
-			allControls := ctx.TerragruntOptions.StrictControls
-
-			skipDependenciesInputs := allControls.Find(controls.SkipDependenciesInputs)
-			if skipDependenciesInputs == nil {
-				return nil, errors.New("failed to find control " + controls.SkipDependenciesInputs)
-			}
-
-			skipDependenciesInputs.SuppressWarning()
-
-			if err := skipDependenciesInputs.Evaluate(ctx); err != nil {
-				l.Debugf(
-					"Skipping inputs parse from %v in dependency for better performance, due to usage of %s strict control",
-					file.ConfigPath,
-					controls.SkipDependenciesInputs,
-				)
-
-				break
-			}
-
-			decoded := terragruntInputs{}
-
-			if _, ok := evalParsingContext.Variables[MetadataDependency]; !ok {
-				// Decode just the `dependency` blocks, retrieving the outputs from the target terragrunt config in the process.
-				retrievedOutputs, err := decodeAndRetrieveOutputs(ctx, l, file)
-				if err != nil {
-					return nil, err
-				}
-
-				evalParsingContext.Variables[MetadataDependency] = *retrievedOutputs
-			}
-
-			if err := file.Decode(&decoded, evalParsingContext); err != nil {
-				var diagErr hcl.Diagnostics
-
-				ok := errors.As(err, &diagErr)
-
-				// in case of render-json command and inputs reference error, we update the inputs with default value
-				if !ok || !isRenderJSONCommand(ctx) || !isRenderCommand(ctx) || !isAttributeAccessError(diagErr) {
-					return nil, err
-				}
-
-				l.Warnf("Failed to decode inputs %v", diagErr)
-			}
-
-			if decoded.Inputs != nil {
-				inputs, err := ctyhelper.ParseCtyValueToMap(*decoded.Inputs)
-				if err != nil {
-					return nil, err
-				}
-
-				output.Inputs = inputs
-			}
-
 		case TerragruntVersionConstraints:
 			decoded := terragruntVersionConstraints{}
 
