@@ -249,7 +249,7 @@ func decodeDependencies(ctx *ParsingContext, l log.Logger, decodedDependency Ter
 					return nil, err
 				}
 
-				depCtx := ctx.WithDecodeList(TerragruntFlags, TerragruntInputs).WithTerragruntOptions(depOpts)
+				depCtx := ctx.WithDecodeList(TerragruntFlags).WithTerragruntOptions(depOpts)
 
 				if depConfig, err := PartialParseConfigFile(depCtx, l, depPath, nil); err == nil {
 					if depConfig.Skip != nil && *depConfig.Skip {
@@ -718,7 +718,8 @@ func cloneTerragruntOptionsForDependencyOutput(ctx *ParsingContext, l log.Logger
 		return l, nil, err
 	}
 
-	if partialTerragruntConfig.TerraformBinary != "" {
+	// Only override TFPath if it was not explicitly set by the user via CLI or environment variable
+	if !targetOptions.TFPathExplicitlySet && partialTerragruntConfig.TerraformBinary != "" {
 		targetOptions.TFPath = partialTerragruntConfig.TerraformBinary
 	}
 
