@@ -8,13 +8,13 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
-	"sort"
 	"strings"
 	"sync"
 
 	"github.com/gruntwork-io/terragrunt/config/hclparse"
 	"github.com/gruntwork-io/terragrunt/internal/runner/common"
 
+	"github.com/gruntwork-io/terragrunt/internal/component"
 	"github.com/gruntwork-io/terragrunt/internal/experiment"
 	"github.com/gruntwork-io/terragrunt/util"
 
@@ -31,11 +31,6 @@ import (
 )
 
 const (
-	// ConfigTypeUnit is the type of Terragrunt configuration for a unit.
-	ConfigTypeUnit ConfigType = "unit"
-	// ConfigTypeStack is the type of Terragrunt configuration for a stack.
-	ConfigTypeStack ConfigType = "stack"
-
 	// skipOutputDiagnostics is a string used to identify diagnostics that reference outputs.
 	skipOutputDiagnostics = "output"
 
@@ -79,43 +74,13 @@ var defaultExcludeDirs = []string{
 	".terragrunt-cache/**",
 }
 
-// ConfigType is the type of Terragrunt configuration.
-type ConfigType string
-
 // Sort is the sort order of the discovered configurations.
 type Sort string
 
-// DiscoveredConfig represents a discovered Terragrunt configuration.
-type DiscoveredConfig struct {
-	Parsed           *config.TerragruntConfig
-	DiscoveryContext *DiscoveryContext
-
-	Type ConfigType
-	Path string
-
-	Dependencies DiscoveredConfigs
-
-	External bool
-}
-
-// DiscoveryContext is the context in which
-// a DiscoveredConfig was discovered.
-//
-// It's useful to know this information,
-// because it can help us determine how the
-// DiscoveredConfig should be processed later.
-type DiscoveryContext struct {
-	Cmd  string
-	Args []string
-}
-
-// DiscoveredConfigs is a list of discovered Terragrunt configurations.
-type DiscoveredConfigs []*DiscoveredConfig
-
 // Discovery is the configuration for a Terragrunt discovery.
 type Discovery struct {
 	// discoveryContext is the context in which the discovery is happening.
-	discoveryContext *DiscoveryContext
+	discoveryContext *component.DiscoveryContext
 
 	// workingDir is the directory to search for Terragrunt configurations.
 	workingDir string
@@ -285,7 +250,7 @@ func (d *Discovery) WithSuppressParseErrors() *Discovery {
 }
 
 // WithDiscoveryContext sets the DiscoveryContext flag to the given context.
-func (d *Discovery) WithDiscoveryContext(discoveryContext *DiscoveryContext) *Discovery {
+func (d *Discovery) WithDiscoveryContext(discoveryContext *component.DiscoveryContext) *Discovery {
 	d.discoveryContext = discoveryContext
 
 	return d
@@ -402,20 +367,21 @@ func (d *Discovery) compileExcludePatterns(l log.Logger) {
 	}
 }
 
-// String returns a string representation of a DiscoveredConfig.
-func (c *DiscoveredConfig) String() string {
+// String returns a string representation of a Component.
+// String returns the path of the Component.
+func String(c *component.Component) string {
 	return c.Path
 }
 
-// ContainsDependencyInAncestry returns true if the DiscoveredConfig or any of
+// ContainsDependencyInAncestry returns true if the Component or any of
 // its dependencies contains the given path as a dependency.
-func (c *DiscoveredConfig) ContainsDependencyInAncestry(path string) bool {
+func ContainsDependencyInAncestry(c *component.Component, path string) bool {
 	for _, dep := range c.Dependencies {
 		if dep.Path == path {
 			return true
 		}
 
-		if dep.ContainsDependencyInAncestry(path) {
+		if ContainsDependencyInAncestry(dep, path) {
 			return true
 		}
 	}
@@ -423,8 +389,8 @@ func (c *DiscoveredConfig) ContainsDependencyInAncestry(path string) bool {
 	return false
 }
 
-// Parse parses the discovered configurations.
-func (c *DiscoveredConfig) Parse(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, suppressParseErrors bool, parserOptions []hclparse.Option) error {
+// Parse parses the discovered configuration.
+func Parse(c *component.Component, ctx context.Context, l log.Logger, opts *options.TerragruntOptions, suppressParseErrors bool, parserOptions []hclparse.Option) error {
 	parseOpts := opts.Clone()
 	parseOpts.WorkingDir = c.Path
 
@@ -443,7 +409,7 @@ func (c *DiscoveredConfig) Parse(ctx context.Context, l log.Logger, opts *option
 	}
 
 	// For stack configurations, always use the default stack config filename
-	if c.Type == ConfigTypeStack {
+	if c.Kind == component.Stack {
 		filename = config.DefaultStackFile
 	}
 
@@ -545,12 +511,12 @@ func (d *Discovery) discoverConcurrently(
 	l log.Logger,
 	opts *options.TerragruntOptions,
 	filenames []string,
-) (DiscoveredConfigs, error) {
+) (component.Components, error) {
 	g, ctx := errgroup.WithContext(ctx)
 	g.SetLimit(d.numWorkers + 1) // +1 for the file walker
 
 	filePaths := make(chan string, d.numWorkers*channelBufferMultiplier)
-	results := make(chan *DiscoveredConfig, d.numWorkers*channelBufferMultiplier)
+	results := make(chan *component.Component, d.numWorkers*channelBufferMultiplier)
 
 	g.Go(func() error {
 		defer close(filePaths)
@@ -570,7 +536,7 @@ func (d *Discovery) discoverConcurrently(
 		_ = g.Wait() // We handle errors in the main thread below
 	}()
 
-	cfgs := make(DiscoveredConfigs, 0, len(results))
+	cfgs := make(component.Components, 0, len(results))
 
 	for config := range results {
 		cfgs = append(cfgs, config)
@@ -644,7 +610,7 @@ func (d *Discovery) configWorker(
 	ctx context.Context,
 	l log.Logger,
 	filePaths <-chan string,
-	results chan<- *DiscoveredConfig,
+	results chan<- *component.Component,
 	filenames []string,
 ) error {
 	for path := range filePaths {
@@ -669,7 +635,7 @@ func (d *Discovery) configWorker(
 }
 
 // processFile processes a single file to determine if it's a Terragrunt configuration.
-func (d *Discovery) processFile(path string, l log.Logger, filenames []string) *DiscoveredConfig {
+func (d *Discovery) processFile(path string, l log.Logger, filenames []string) *component.Component {
 	dir := filepath.Dir(path)
 
 	canonicalDir, canErr := util.CanonicalPath(dir, d.workingDir)
@@ -729,13 +695,13 @@ func (d *Discovery) processFile(path string, l log.Logger, filenames []string) *
 	base := filepath.Base(path)
 	for _, fname := range filenames {
 		if base == fname {
-			cfgType := ConfigTypeUnit
+			cfgType := component.Unit
 			if fname == config.DefaultStackFile {
-				cfgType = ConfigTypeStack
+				cfgType = component.Stack
 			}
 
-			cfg := &DiscoveredConfig{
-				Type: cfgType,
+			cfg := &component.Component{
+				Kind: cfgType,
 				Path: filepath.Dir(path),
 			}
 			if d.discoveryContext != nil {
@@ -750,14 +716,14 @@ func (d *Discovery) processFile(path string, l log.Logger, filenames []string) *
 }
 
 // parseConcurrently parses configurations concurrently to improve performance using errgroup.
-func (d *Discovery) parseConcurrently(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, cfgs DiscoveredConfigs) []error {
+func (d *Discovery) parseConcurrently(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, cfgs component.Components) []error {
 	// Filter out configs that don't need parsing
 	// Pre-allocate with estimated capacity to reduce reallocation
-	configsToParse := make([]*DiscoveredConfig, 0, len(cfgs))
+	configsToParse := make([]*component.Component, 0, len(cfgs))
 	for _, cfg := range cfgs {
 		// Stack configurations don't need to be parsed for discovery purposes.
 		// They don't have exclude blocks or dependencies.
-		if cfg.Type == ConfigTypeStack {
+		if cfg.Kind == component.Stack {
 			continue
 		}
 
@@ -773,7 +739,7 @@ func (d *Discovery) parseConcurrently(ctx context.Context, l log.Logger, opts *o
 	g.SetLimit(d.numWorkers)
 
 	// Use channels to coordinate parsing work
-	configChan := make(chan *DiscoveredConfig, d.numWorkers*channelBufferMultiplier)
+	configChan := make(chan *component.Component, d.numWorkers*channelBufferMultiplier)
 	errorChan := make(chan error, len(configsToParse))
 
 	// Start config sender
@@ -823,7 +789,7 @@ func (d *Discovery) parseConcurrently(ctx context.Context, l log.Logger, opts *o
 }
 
 // parseWorker is a worker that parses configurations concurrently.
-func (d *Discovery) parseWorker(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, configChan <-chan *DiscoveredConfig, errorChan chan<- error) error {
+func (d *Discovery) parseWorker(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, configChan <-chan *component.Component, errorChan chan<- error) error {
 	for cfg := range configChan {
 		// Context cancellation check
 		select {
@@ -832,7 +798,7 @@ func (d *Discovery) parseWorker(ctx context.Context, l log.Logger, opts *options
 		default:
 		}
 
-		err := cfg.Parse(ctx, l, opts, d.suppressParseErrors, d.parserOptions)
+		err := Parse(cfg, ctx, l, opts, d.suppressParseErrors, d.parserOptions)
 
 		// Send error or handle context cancellation
 		select {
@@ -846,7 +812,7 @@ func (d *Discovery) parseWorker(ctx context.Context, l log.Logger, opts *options
 }
 
 // Discover discovers Terragrunt configurations in the WorkingDir.
-func (d *Discovery) Discover(ctx context.Context, l log.Logger, opts *options.TerragruntOptions) (DiscoveredConfigs, error) {
+func (d *Discovery) Discover(ctx context.Context, l log.Logger, opts *options.TerragruntOptions) (component.Components, error) {
 	// Set default config filenames if not set
 	filenames := d.configFilenames
 	if len(filenames) == 0 {
@@ -964,7 +930,7 @@ func (d *Discovery) Discover(ctx context.Context, l log.Logger, opts *options.Te
 
 				var removeErr error
 
-				cfgs, removeErr = cfgs.RemoveCycles()
+				cfgs, removeErr = RemoveCycles(cfgs)
 				if removeErr != nil {
 					errs = append(errs, errors.New(removeErr))
 				}
@@ -986,8 +952,8 @@ func (d *Discovery) Discover(ctx context.Context, l log.Logger, opts *options.Te
 
 // DependencyDiscovery is the configuration for a DependencyDiscovery.
 type DependencyDiscovery struct {
-	discoveryContext    *DiscoveryContext
-	cfgs                DiscoveredConfigs
+	discoveryContext    *component.DiscoveryContext
+	cfgs                component.Components
 	parserOptions       []hclparse.Option
 	depthRemaining      int
 	discoverExternal    bool
@@ -998,7 +964,7 @@ type DependencyDiscovery struct {
 // DependencyDiscoveryOption is a function that modifies a DependencyDiscovery.
 type DependencyDiscoveryOption func(*DependencyDiscovery)
 
-func NewDependencyDiscovery(cfgs DiscoveredConfigs, depthRemaining int) *DependencyDiscovery {
+func NewDependencyDiscovery(cfgs component.Components, depthRemaining int) *DependencyDiscovery {
 	return &DependencyDiscovery{
 		cfgs:           cfgs,
 		depthRemaining: depthRemaining,
@@ -1031,7 +997,7 @@ func (d *DependencyDiscovery) WithParserOptions(options []hclparse.Option) *Depe
 	return d
 }
 
-func (d *DependencyDiscovery) WithDiscoveryContext(discoveryContext *DiscoveryContext) *DependencyDiscovery {
+func (d *DependencyDiscovery) WithDiscoveryContext(discoveryContext *component.DiscoveryContext) *DependencyDiscovery {
 	d.discoveryContext = discoveryContext
 
 	return d
@@ -1041,7 +1007,7 @@ func (d *DependencyDiscovery) DiscoverAllDependencies(ctx context.Context, l log
 	errs := []error{}
 
 	for _, cfg := range d.cfgs {
-		if cfg.Type == ConfigTypeStack {
+		if cfg.Kind == component.Stack {
 			continue
 		}
 
@@ -1058,20 +1024,20 @@ func (d *DependencyDiscovery) DiscoverAllDependencies(ctx context.Context, l log
 	return nil
 }
 
-func (d *DependencyDiscovery) DiscoverDependencies(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, dCfg *DiscoveredConfig) error {
+func (d *DependencyDiscovery) DiscoverDependencies(ctx context.Context, l log.Logger, opts *options.TerragruntOptions, dCfg *component.Component) error {
 	if d.depthRemaining <= 0 {
 		return errors.New("max dependency depth reached while discovering dependencies")
 	}
 
 	// Stack configs don't have dependencies (at least for now),
 	// so we can return early.
-	if dCfg.Type == ConfigTypeStack {
+	if dCfg.Kind == component.Stack {
 		return nil
 	}
 
 	// This should only happen if we're discovering an ancestor dependency.
 	if dCfg.Parsed == nil {
-		err := dCfg.Parse(ctx, l, opts, d.suppressParseErrors, d.parserOptions)
+		err := Parse(dCfg, ctx, l, opts, d.suppressParseErrors, d.parserOptions)
 		if err != nil {
 			return errors.New(err)
 		}
@@ -1142,8 +1108,8 @@ func (d *DependencyDiscovery) DiscoverDependencies(ctx context.Context, l log.Lo
 				continue
 			}
 
-			ext := &DiscoveredConfig{
-				Type:     ConfigTypeUnit,
+			ext := &component.Component{
+				Kind:     component.Unit,
 				Path:     depPath,
 				External: true,
 			}
@@ -1172,112 +1138,11 @@ func (d *DependencyDiscovery) DiscoverDependencies(ctx context.Context, l log.Lo
 	return nil
 }
 
-// Sort sorts the DiscoveredConfigs by path.
-func (c DiscoveredConfigs) Sort() DiscoveredConfigs {
-	sort.Slice(c, func(i, j int) bool {
-		return c[i].Path < c[j].Path
-	})
-
-	return c
-}
-
-// Filter filters the DiscoveredConfigs by config type.
-func (c DiscoveredConfigs) Filter(configType ConfigType) DiscoveredConfigs {
-	filtered := make(DiscoveredConfigs, 0, len(c))
-
-	for _, config := range c {
-		if config.Type == configType {
-			filtered = append(filtered, config)
-		}
-	}
-
-	return filtered
-}
-
-// FilterByPath filters the DiscoveredConfigs by path.
-func (c DiscoveredConfigs) FilterByPath(path string) DiscoveredConfigs {
-	filtered := make(DiscoveredConfigs, 0, 1)
-
-	for _, config := range c {
-		if config.Path == path {
-			filtered = append(filtered, config)
-		}
-	}
-
-	return filtered
-}
-
-// RemoveByPath removes the DiscoveredConfig with the given path from the DiscoveredConfigs.
-func (c DiscoveredConfigs) RemoveByPath(path string) DiscoveredConfigs {
-	filtered := make(DiscoveredConfigs, 0, len(c)-1)
-
-	for _, config := range c {
-		if config.Path != path {
-			filtered = append(filtered, config)
-		}
-	}
-
-	return filtered
-}
-
-// Paths returns the paths of the DiscoveredConfigs.
-func (c DiscoveredConfigs) Paths() []string {
-	paths := make([]string, 0, len(c))
-	for _, config := range c {
-		paths = append(paths, config.Path)
-	}
-
-	return paths
-}
-
-// CycleCheck checks for cycles in the dependency graph.
-// If a cycle is detected, it returns the first DiscoveredConfig that is part of the cycle, and an error.
-// If no cycle is detected, it returns nil and nil.
-func (c DiscoveredConfigs) CycleCheck() (*DiscoveredConfig, error) {
-	visited := make(map[string]bool)
-	inPath := make(map[string]bool)
-
-	var checkCycle func(cfg *DiscoveredConfig) error
-
-	checkCycle = func(cfg *DiscoveredConfig) error {
-		if inPath[cfg.Path] {
-			return errors.New("cycle detected in dependency graph at path: " + cfg.Path)
-		}
-
-		if visited[cfg.Path] {
-			return nil
-		}
-
-		visited[cfg.Path] = true
-		inPath[cfg.Path] = true
-
-		for _, dep := range cfg.Dependencies {
-			if err := checkCycle(dep); err != nil {
-				return err
-			}
-		}
-
-		inPath[cfg.Path] = false
-
-		return nil
-	}
-
-	for _, cfg := range c {
-		if !visited[cfg.Path] {
-			if err := checkCycle(cfg); err != nil {
-				return cfg, err
-			}
-		}
-	}
-
-	return nil, nil
-}
-
 // RemoveCycles removes cycles from the dependency graph.
-func (c DiscoveredConfigs) RemoveCycles() (DiscoveredConfigs, error) {
+func RemoveCycles(c component.Components) (component.Components, error) {
 	var (
 		err error
-		cfg *DiscoveredConfig
+		cfg *component.Component
 	)
 
 	for range maxCycleRemovalAttempts {
